@@ -6,7 +6,7 @@ struct MyItem {
 }
 
 impl SkimItem for MyItem {
-    fn text(&self) -> Cow<str> {
+    fn text(&self) -> Cow<'_, str> {
         Cow::Borrowed(&self.inner)
     }
 
@@ -19,11 +19,11 @@ impl SkimItem for MyItem {
     }
 }
 
-pub fn main() {
+fn main() {
     let options = SkimOptionsBuilder::default()
-        .height(Some("50%"))
+        .height(String::from("50%"))
         .multi(true)
-        .preview(Some("")) // preview should be specified to enable preview window
+        .preview(Some(String::new())) // preview should be specified to enable preview window
         .build()
         .unwrap();
 
@@ -39,9 +39,9 @@ pub fn main() {
     }));
     drop(tx_item); // so that skim could know when to stop waiting for more items.
 
-    let selected_items = Skim::run_with(&options, Some(rx_item))
+    let selected_items = Skim::run_with(options, Some(rx_item))
         .map(|out| out.selected_items)
-        .unwrap_or_else(Vec::new);
+        .unwrap_or_default();
 
     for item in selected_items.iter() {
         println!("{}", item.output());
